playdate-rs 0.0.2

Rust type-safe bindings for the Playdate SDK
docs.rs failed to build playdate-rs-0.0.2
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: playdate-rs-0.0.15

playdate-rs

Placeholder for the Rust-safe bindings to the Playdate SDK