Struct playdate_rs::display::Display
source · pub struct Display { /* private fields */ }Implementations
sourceimpl Display
impl Display
sourcepub fn get_width(&self) -> i32
pub fn get_width(&self) -> i32
Returns the height of the display, taking the current scale into account; e.g., if the scale is 2, this function returns 120 instead of 240.
sourcepub fn get_height(&self) -> i32
pub fn get_height(&self) -> i32
Returns the width of the display, taking the current scale into account; e.g., if the scale is 2, this function returns 200 instead of 400.
sourcepub fn set_refresh_rate(&self, rate: f32)
pub fn set_refresh_rate(&self, rate: f32)
Sets the nominal refresh rate in frames per second. Default is 20 fps, the maximum rate supported by the hardware for full-frame updates.
sourcepub fn set_inverted(&self, flag: i32)
pub fn set_inverted(&self, flag: i32)
If flag evaluates to true, the frame buffer is drawn inverted—black instead of white, and vice versa.
sourcepub fn set_scale(&self, s: u32)
pub fn set_scale(&self, s: u32)
Sets the display scale factor. Valid values for scale are 1, 2, 4, and 8.
The top-left corner of the frame buffer is scaled up to fill the display; e.g., if the scale is set to 4, the pixels in rectangle [0,100] x [0,60] are drawn on the screen as 4 x 4 squares.
sourcepub fn set_mosaic(&self, x: u32, y: u32)
pub fn set_mosaic(&self, x: u32, y: u32)
Adds a mosaic effect to the display. Valid x and y values are between 0 and 3, inclusive.
sourcepub fn set_flipped(&self, x: i32, y: i32)
pub fn set_flipped(&self, x: i32, y: i32)
Flips the display on the x or y axis, or both.
sourcepub fn set_offset(&self, x: i32, y: i32)
pub fn set_offset(&self, x: i32, y: i32)
Offsets the display by the given amount. Areas outside of the displayed area are filled with the current background color.