MenuItem

Struct MenuItem 

pub struct MenuItem { /* private fields */ }

Implementations

Source

impl MenuItem

pub fn get_value(&self) -> i32

Gets the integer value of the menu item.

For checkmark menu items, 1 means checked, 0 unchecked. For option menu items, the value indicates the array index of the currently selected option.

pub fn set_value(&self, value: i32)

Sets the integer value of the menu item.

For checkmark menu items, 1 means checked, 0 unchecked. For option menu items, the value indicates the array index of the currently selected option.

pub fn get_title(&self) -> &str

Gets the display title of the menu item.

pub fn set_title(&self, title: impl AsRef<str>)

Sets the display title of the menu item.