Struct playdate_rs::video::Video
source · pub struct Video { /* private fields */ }Implementations
sourceimpl Video
impl Video
sourcepub fn load(&self, path: impl AsRef<str>) -> Result<VideoPlayer, String>
pub fn load(&self, path: impl AsRef<str>) -> Result<VideoPlayer, String>
Opens the pdv file at path and returns a new video player object for rendering its frames.
sourcepub fn use_screen_context(&self, player: &VideoPlayer)
pub fn use_screen_context(&self, player: &VideoPlayer)
Sets the rendering destination for the video player to the screen.