pub struct PlaydateDisplay { /* private fields */ }Implementations
Sourceimpl PlaydateDisplay
impl PlaydateDisplay
Sourcepub fn get_width(&self) -> u32
pub fn get_width(&self) -> u32
Returns the height of the display, taking the current scale into account; e.g., if the scale is 2, this function returns 120 instead of 240.
Sourcepub fn get_height(&self) -> u32
pub fn get_height(&self) -> u32
Returns the width of the display, taking the current scale into account; e.g., if the scale is 2, this function returns 200 instead of 400.
Sourcepub fn set_refresh_rate(&self, rate: f32)
pub fn set_refresh_rate(&self, rate: f32)
Sets the nominal refresh rate in frames per second. Default is 20 fps, the maximum rate supported by the hardware for full-frame updates.
Sourcepub fn set_inverted(&self, flag: bool)
pub fn set_inverted(&self, flag: bool)
If flag evaluates to true, the frame buffer is drawn inverted—black instead of white, and vice versa.
Sourcepub fn set_scale(&self, s: u32)
pub fn set_scale(&self, s: u32)
Sets the display scale factor. Valid values for scale are 1, 2, 4, and 8.
The top-left corner of the frame buffer is scaled up to fill the display; e.g., if the scale is set to 4, the pixels in rectangle [0,100] x [0,60] are drawn on the screen as 4 x 4 squares.
Sourcepub fn set_mosaic(&self, effect: Vec2<u32>)
pub fn set_mosaic(&self, effect: Vec2<u32>)
Adds a mosaic effect to the display. Valid x and y values are between 0 and 3, inclusive.
Sourcepub fn set_flipped(&self, x: bool, y: bool)
pub fn set_flipped(&self, x: bool, y: bool)
Flips the display on the x or y axis, or both.
Sourcepub fn set_offset(&self, delta: Vec2<i32>)
pub fn set_offset(&self, delta: Vec2<i32>)
Offsets the display by the given amount. Areas outside of the displayed area are filled with the current background color.