pub struct BitmapTable { /* private fields */ }
There are two kinds of image tables: matrix and sequential.

Matrix image tables are great as sources of imagery for tilemap. They are loaded from a single file in your game’s source folder with the suffix -table-- before the file extension. The compiler splits the image into separate bitmaps of dimension w by h pixels that are accessible via imagetable:getImage(x,y).

Sequential image tables are useful as a way to load up sequential frames of animation. They are loaded from a sequence of files in your game’s source folder at compile time from filenames with the suffix -table- before the file extension. Individual images in the sequence are accessible via imagetable:getImage(n). The images employed by a sequential image table are not required to be the same size, unlike the images used in a matrix image table.

Implementations

source

impl BitmapTable

source

pub fn new(count: usize, width: usize, height: usize) -> Self

source

pub fn get(&self, idx: usize) -> Option<Ref<'_, Bitmap>>

Returns the idx bitmap in table, If idx is out of bounds, the function returns NULL.

source

pub fn load(&self, path: impl AsRef<str>) -> Result<(), Error>

Allocates and returns a new LCDBitmap from the file at path. If there is no file at path, the function returns null.