Struct playdate_rs::system::Buttons

source ·
#[repr(transparent)]
pub struct Buttons { /* private fields */ }

Implementations

source

impl Buttons

source

pub const Left: Buttons = _

source

pub const Right: Buttons = _

source

pub const Up: Buttons = _

source

pub const Down: Buttons = _

source

pub const B: Buttons = _

source

pub const A: Buttons = _

source

pub const fn bits(&self) -> u8

Returns the underlying bits of the bitmask.

source

pub const fn all() -> Self

Returns a bitmask that contains all values.

This will include bits that do not have any flags. Use ::full() if you only want to use flags.

source

pub const fn is_all(&self) -> bool

Returns true if the bitmask contains all values.

This will check for bits == !0, use .is_full() if you only want to check for all flags

source

pub const fn none() -> Self

Returns a bitmask that does not contain any values.

source

pub const fn is_none(&self) -> bool

Returns true if the bitmask does not contain any values.

source

pub const fn full() -> Self

Returns a bitmask that contains all flags.

source

pub const fn is_full(&self) -> bool

Returns true if the bitmask contains all flags.

This will fail if any unused bit is set, consider using .truncate() first.

source

pub const fn truncate(&self) -> Self

Returns a bitmask that only has bits corresponding to flags

source

pub const fn intersects(&self, other: Self) -> bool

Returns true if self intersects with any value in other, or if other does not contain any values.

This is equivalent to (self & other) != 0 || other == 0.

source

pub const fn contains(&self, other: Self) -> bool

Returns true if self contains all values of other.

This is equivalent to (self & other) == other.

source

pub const fn not(self) -> Self

Returns the bitwise NOT of the bitmask.

source

pub const fn and(self, other: Self) -> Self

Returns the bitwise AND of the bitmask.

source

pub const fn or(self, other: Self) -> Self

Returns the bitwise OR of the bitmask.

source

pub const fn xor(self, other: Self) -> Self

Returns the bitwise XOR of the bitmask.