Struct playdate_rs::system::Buttons
source · #[repr(transparent)]pub struct Buttons { /* private fields */ }Implementations
sourceimpl Buttons
impl Buttons
pub const Left: Buttons = _
pub const Right: Buttons = _
pub const Up: Buttons = _
pub const Down: Buttons = _
pub const B: Buttons = _
pub const A: Buttons = _
sourcepub const fn all() -> Self
pub const fn all() -> Self
Returns a bitmask that contains all values.
This will include bits that do not have any flags.
Use ::full() if you only want to use flags.
sourcepub const fn is_all(&self) -> bool
pub const fn is_all(&self) -> bool
Returns true if the bitmask contains all values.
This will check for bits == !0,
use .is_full() if you only want to check for all flags
sourcepub const fn is_full(&self) -> bool
pub const fn is_full(&self) -> bool
Returns true if the bitmask contains all flags.
This will fail if any unused bit is set,
consider using .truncate() first.
sourcepub const fn truncate(&self) -> Self
pub const fn truncate(&self) -> Self
Returns a bitmask that only has bits corresponding to flags
sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Returns true if self intersects with any value in other,
or if other does not contain any values.
This is equivalent to (self & other) != 0 || other == 0.