pub struct VideoPlayer { /* private fields */ }Implementations
Sourceimpl VideoPlayer
impl VideoPlayer
Sourcepub fn load(&self, path: impl AsRef<str>) -> Result<Self, Error>
pub fn load(&self, path: impl AsRef<str>) -> Result<Self, Error>
Opens the pdv file at path and returns a new video player object for rendering its frames.
Sourcepub fn set_context<'a, 'b: 'a>(
&'a self,
context: &'b Bitmap,
) -> Result<(), Error>
pub fn set_context<'a, 'b: 'a>( &'a self, context: &'b Bitmap, ) -> Result<(), Error>
Sets the rendering destination for the video player to the given bitmap.
Sourcepub fn get_context(&self) -> Ref<'_, Bitmap>
pub fn get_context(&self) -> Ref<'_, Bitmap>
Gets the rendering destination for the video player. If no rendering context has been setallocates a context bitmap with the same dimensions as the vieo will be allocated.
Sourcepub fn render_frame(&self, n: usize) -> Result<(), Error>
pub fn render_frame(&self, n: usize) -> Result<(), Error>
Renders frame number n into the current context.
Sourcepub fn get_info(&self) -> VideoPlayerInfo
pub fn get_info(&self) -> VideoPlayerInfo
Retrieves information about the video, by passing in (possibly NULL) value pointers.